@@ -84,7 +84,7 @@
 #define KITEMMODELS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KITEMMODELS_NO_DEPRECATED
-#  define KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57300
 #endif
 #ifdef KITEMMODELS_NO_DEPRECATED_WARNINGS
 #  define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0x57300
 #  endif
 #endif
 
